Quick start
===========

These tutorial files detail typical usages of the ETFL package. They
can be found at::

    etfl
    └── tutorials
        ├── benchmark_models.py
        ├── paper_iJO1366_models.py
        └── blah.py

`blah.py` details how to blah with *Escherichia coli*.

We use `optlang`_.

**We recommend you to get a commercial solver, as it has been seen that GLPK's
lack of parallelism significantly increases solving time**

Cheers,

The ETFL team

.. _optlang: https://github.com/biosustain/optlang
